#[non_exhaustive]pub struct TitlecaseOptions {
pub trailing_case: Option<TrailingCase>,
pub leading_adjustment: Option<LeadingAdjustment>,
}Expand description
Various options for controlling titlecasing
See docs of TitlecaseMapper for examples.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trailing_case: Option<TrailingCase>How to handle the rest of the string once the head of the string has been titlecased
Default is TrailingCase::Lower
leading_adjustment: Option<LeadingAdjustment>Whether to start casing at the beginning of the string or at the first relevant character.
Default is LeadingAdjustment::Auto